@@ -24,7 +24,9 @@ Module responsible for various utility functions used in other modules.
 """
 import dataclasses
 import json
+import numbers
 import os
+from typing import Union
 
 import numpy as np
 
@@ -438,7 +440,7 @@ def tree_sequence_html(ts):
                       </td>
                     </tr>
                 """
-        for name, table in ts.tables.name_map.items()
+        for name, table in ts.tables.table_name_map.items()
     )
     return f"""
             <div>
@@ -459,13 +461,14 @@ def tree_sequence_html(ts):
                       <tr>
                         <th style="padding:0;line-height:21px;">
                           <img style="height: 32px;display: inline-block;padding: 3px 5px 3px 0;" src="https://raw.githubusercontent.com/tskit-dev/administrative/main/tskit_logo.svg"/>
-                          <a target="_blank" href="https://tskit.readthedocs.io/en/latest/python-api.html#the-treesequence-class"> Tree Sequence </a>
+                          <a target="_blank" href="https://tskit.dev/tskit/docs/latest/python-api.html#the-treesequence-class"> Tree Sequence </a>
                         </th>
                       </tr>
                     </thead>
                     <tbody>
                       <tr><td>Trees</td><td>{ts.num_trees}</td></tr>
                       <tr><td>Sequence Length</td><td>{ts.sequence_length}</td></tr>
+                      <tr><td>Time Units</td><td>{ts.time_units}</td></tr>
                       <tr><td>Sample Nodes</td><td>{ts.num_samples}</td></tr>
                       <tr><td>Total Size</td><td>{naturalsize(ts.nbytes)}</td></tr>
                       <tr>
@@ -513,7 +516,7 @@ def tree_html(tree):
                       <tr>
                         <th style="padding:0;line-height:21px;">
                           <img style="height: 32px;display: inline-block;padding: 3px 5px 3px 0;" src="https://raw.githubusercontent.com/tskit-dev/administrative/main/tskit_logo.svg"/>
-                          <a target="_blank" href="https://tskit.readthedocs.io/en/latest/python-api.html#the-tree-class"> Tree </a>
+                          <a target="_blank" href="https://tskit.dev/tskit/docs/latest/python-api.html#the-tree-class"> Tree </a>
                         </th>
                       </tr>
                     </thead>
@@ -521,7 +524,7 @@ def tree_html(tree):
                       <tr><td>Index</td><td>{tree.index}</td></tr>
                       <tr><td>Interval</td><td>{tree.interval.left:.8g}-{tree.interval.right:.8g} ({tree.span:.8g})</td></tr>
                       <tr><td>Roots</td><td>{tree.num_roots}</td></tr>
-                      <tr><td>Nodes</td><td>{tree.num_nodes}</td></tr>
+                      <tr><td>Nodes</td><td>{len(tree.preorder())}</td></tr>
                       <tr><td>Sites</td><td>{tree.num_sites}</td></tr>
                       <tr><td>Mutations</td><td>{tree.num_mutations}</td></tr>
                       <tr><td>Total Branch Length</td><td>{tree.total_branch_length:.8g}</td></tr>
@@ -571,3 +574,21 @@ def set_print_options(*, max_lines=40):
     this number the middle of the table will be skipped.
     """
     tskit._print_options = {"max_lines": max_lines}
+
+
+def random_nucleotides(length: numbers.Number, *, seed: Union[int, None] = None) -> str:
+    """
+    Returns a random string of nucleotides of the specified length. Characters
+    are drawn uniformly from the alphabet "ACTG".
+
+    :param int length: The length of the random sequence.
+    :return: A string of the specified length consisting of random nucleotide
+       characters.
+    :rtype: str
+    """
+    if int(length) != length:
+        raise ValueError("length must be an integer")
+    rng = np.random.RandomState(seed)
+    encoded_nucleotides = np.array(list(map(ord, "ACTG")), dtype=np.int8)
+    a = rng.choice(encoded_nucleotides, size=int(length))
+    return a.tobytes().decode("ascii")
